    food:

    	retrieve and parse a new food "nature":
    		#
    		#	This retrieves a food's data from USDA.
    		#
    		import apoplast.clouds.food_USDA.deliveries.one as retrieve_1_food
    		food_USDA = retrieve_1_food.presently (
    			FDC_ID = 2642759,
    			API_ellipse = ""
    		)

    		#
    		#	This parses USDA foods into the nature format.
    		#
    		#		This should use the shared:
    		#			apoplast.shows.natures
    		#
    		import apoplast.clouds.food_USDA.nature as food_USDA_nature
    		nature = food_USDA_nature.create (food_USDA ["data"])

    	structure is is "shows/nature"

    	unquantified ingredients:
    		https://www.nltk.org/